Pool

Struct Pool 

pub struct Pool<T: Send> { /* private fields */ }
A pool of objects. After an object is taken from the pool, it is returned to the pool when it is dropped. Pool items must be passed on creation by values:

Examples

basic usage:

let pool = autoreturn_pool::Pool::new([1, 2]);
let item = pool.take();

with custom config:

let config = autoreturn_pool::Config {
   wait_duration: std::time::Duration::from_millis(5),
};
let pool = autoreturn_pool::Pool::with_config(config, [1, 2]);
let item = pool.take();

Implementations

Source

impl<T: Send + 'static> Pool<T>

pub fn new(items: impl IntoIterator<Item = T>) -> Self

pub fn with_config(config: Config, items: impl IntoIterator<Item = T>) -> Self

pub fn take(&self) -> Option<PoolObject<'_, T>>

Take an object from the pool. If the pool is empty, the method will wait for the object to be returned to the pool. If the wait duration is exceeded, the method will return None.

pub fn add(&self, item: T)

Allows to add new object to the pool.

pub fn size(&self) -> usize

Get the number of available objects in the pool.