Struct autoreturn_pool::Pool

source ·
pub struct Pool<T: Send> { /* private fields */ }
A pool of objects. After an object is taken from the pool, it is returned to the pool when it is dropped. Pool items must be passed on creation by values:

Examples

basic usage:

let pool = autoreturn_pool::Pool::new([1, 2])?;
let item = pool.take()?.unwrap();

with custom config:

let config = autoreturn_pool::Config {
   wait_duration: std::time::Duration::from_millis(5),
};
let pool = autoreturn_pool::Pool::with_config(config, [1, 2])?;
let item = pool.take()?.unwrap();

Implementations

source

impl<T: Send + 'static> Pool<T>

source

pub fn new<I>(items: I) -> Result<Self, Error>
where I: IntoIterator<Item = T>,

source

pub fn with_config<I>(config: Config, items: I) -> Result<Self, Error>
where I: IntoIterator<Item = T>,

source

pub fn take(&self) -> Result<Option<PoolObject<'_, T>>, Error>

source

pub fn size(&self) -> Result<usize, Error>

Get the number of available objects in the pool.