Struct autoreturn_pool::Pool
source · pub struct Pool<T: Send> { /* private fields */ }Expand description
A pool of objects. After an object is taken from the pool, it is returned to the pool when it is dropped. Pool items must be passed on creation by values:
Examples
basic usage:
let pool = autoreturn_pool::Pool::new([1, 2])?;
let item = pool.take()?.unwrap();with custom config:
let config = autoreturn_pool::Config {
wait_duration: std::time::Duration::from_millis(5),
};
let pool = autoreturn_pool::Pool::with_config(config, [1, 2])?;
let item = pool.take()?.unwrap();Implementations